flex: Lexical analyzer generator
================================

Description
-----------

This dummy package represents GNU flex.

We do not have an SPKG for it. The purpose of this dummy package is to
associate system package lists with it.
